..
    DO NOT EDIT
    This file is automatically generated with copier using https://codeberg.org/slidge/legacy-module-template

For users
=========

You want to use a matridge instance? You have come to the right place.

.. toctree::

  registration
  usage
  features
